@@ -76,7 +76,9 @@ class Job:
         self.date_updated: Optional[datetime] = (
             str_to_datetime(dateUpdated) if dateCreated else None
         )
-        self.resource: Optional[Resource] = Resource.from_dict(resource)
+        self.resource: Optional[Resource] = (
+            Resource.from_dict(resource) if resource else None
+        )
         self.child_jobs: Optional[List[Job]] = (
             list(map(lambda x: Job.from_dict(x), childJobs)) if childJobs else None
         )
